@@ -293,14 +293,16 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
     # ensure yarn installs all build tools
+    yarn_cache=os.getenv('PWD','') + '.yarn_cache/'
+    local('mkdir -p .yarn_cache/')
     with lcd(installPath):
         local("pwd")
-        local('yarn --production=false --no-progress --non-interactive install')
+        local('yarn --production=false --no-progress --non-interactive --cache-folder %s install' % yarn_cache)
 
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('yarn build %s %s' % (options, ngApp))
+            local('yarn build %s %s --cache-folder %s ' % (options, ngApp, yarn_cache))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
@@ -327,7 +329,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 def build2():
 
 
-    # ensure yarn installs all build tools
+    # ensure maven installs all build tools
     local("pwd")
     local('mvn clean install -DskipTests')
     local('mkdir -p deploy/api/config')
@@ -382,7 +384,7 @@ def tar_from_git(branch, dirs=None, baseDir='.'):
                   (branch, TAR_NAME))
 
     if baseDir != '.':
-        local('mv %s/%s.tar.gz .')
+        local('mv %s/%s.tar.gz .' % (baseDir, TAR_NAME))
 
 @task
 def clean_up():
